==> snd-7.8.tar.gz: snd-7/sndlib-strings.h <==
#ifndef SNDLIB_STRINGS_H
#define SNDLIB_STRINGS_H

#define S_make_sound_data               "make-sound-data"
#define S_mus_aifc                      "mus-aifc"
#define S_mus_aiff                      "mus-aiff"
#define S_mus_alaw                      "mus-alaw"
#define S_mus_audio_adat_in             "mus-audio-adat-in"
#define S_mus_audio_adat_out            "mus-audio-adat-out"
#define S_mus_audio_aes_in              "mus-audio-aes-in"
#define S_mus_audio_aes_out             "mus-audio-aes-out"
#define S_mus_audio_amp                 "mus-audio-amp"
#define S_mus_audio_aux_input           "mus-audio-aux-input"
#define S_mus_audio_aux_output          "mus-audio-aux-output"
#define S_mus_audio_bass                "mus-audio-bass"
#define S_mus_audio_cd                  "mus-audio-cd"
#define S_mus_audio_channel             "mus-audio-channel"
#define S_mus_audio_close               "mus-audio-close"
#define S_mus_audio_dac_filter          "mus-audio-dac-filter"
#define S_mus_audio_dac_out             "mus-audio-dac-out"
#define S_mus_audio_default             "mus-audio-default"
#define S_mus_audio_digital_in          "mus-audio-digital-in"
#define S_mus_audio_digital_out         "mus-audio-digital-out"
#define S_mus_audio_direction           "mus-audio-direction"
#define S_mus_audio_duplex_default      "mus-audio-duplex-default"
#define S_mus_audio_format              "mus-audio-format"
#define S_mus_audio_igain               "mus-audio-igain"
#define S_mus_audio_imix                "mus-audio-imix"
#define S_mus_audio_line                "mus-audio-line"
#define S_mus_audio_line1               "mus-audio-line1"
#define S_mus_audio_line2               "mus-audio-line2"
#define S_mus_audio_line3               "mus-audio-line3"
#define S_mus_audio_line_in             "mus-audio-line-in"
#define S_mus_audio_line_out            "mus-audio-line-out"
#define S_mus_audio_microphone          "mus-audio-microphone"
#define S_mus_audio_mixer               "mus-audio-mixer"
#define S_mus_audio_mixer_read          "mus-audio-mixer-read"
#define S_mus_audio_mixer_write         "mus-audio-mixer-write"
#define S_mus_audio_ogain               "mus-audio-ogain"
#define S_mus_audio_open_input          "mus-audio-open-input"
#define S_mus_audio_open_output         "mus-audio-open-output"
#define S_mus_audio_pcm                 "mus-audio-pcm"
#define S_mus_audio_pcm2                "mus-audio-pcm2"
#define S_mus_audio_port                "mus-audio-port"
#define S_mus_audio_read                "mus-audio-read"
#define S_mus_audio_reclev              "mus-audio-reclev"
#define S_mus_audio_report              "mus-audio-report"
#define S_mus_audio_samples_per_channel "mus-audio-samples-per-channel"
#define S_mus_audio_set_oss_buffers     "mus-audio-set-oss-buffers"
#define S_mus_audio_spdif_in            "mus-audio-spdif-in"
#define S_mus_audio_spdif_out           "mus-audio-spdif-out"
#define S_mus_audio_speakers            "mus-audio-speakers"
#define S_mus_audio_srate               "mus-audio-srate"
#define S_mus_audio_sun_outputs         "mus-audio-sun-outputs"
#define S_mus_audio_synth               "mus-audio-synth"
#define S_mus_audio_systems             "mus-audio-systems"
#define S_mus_audio_treble              "mus-audio-treble"
#define S_mus_audio_write               "mus-audio-write"
#define S_mus_b24int                    "mus-b24int"
#define S_mus_bdouble                   "mus-bdouble"
#define S_mus_bdouble_unscaled          "mus-bdouble-unscaled"
#define S_mus_bfloat                    "mus-bfloat"
#define S_mus_bfloat_unscaled           "mus-bfloat-unscaled"
#define S_mus_bicsf                     "mus-bicsf"
#define S_mus_bint                      "mus-bint"
#define S_mus_bintn                     "mus-bintn"
#define S_mus_bshort                    "mus-bshort"
#define S_mus_byte                      "mus-byte"
#define S_mus_bytes_per_sample          "mus-bytes-per-sample"
#define S_mus_data_format_name          "mus-data-format-name"
#define S_mus_error_to_string           "mus-error-to-string"
#define S_mus_expand_filename           "mus-expand-filename"
#define S_mus_file_data_clipped         "mus-file-data-clipped"
#define S_mus_file_prescaler            "mus-file-prescaler"
#define S_mus_header_type_name          "mus-header-type-name"
#define S_mus_ircam                     "mus-ircam"
#define S_mus_l24int                    "mus-l24int"
#define S_mus_ldouble                   "mus-ldouble"
#define S_mus_ldouble_unscaled          "mus-ldouble-unscaled"
#define S_mus_lfloat                    "mus-lfloat"
#define S_mus_lfloat_unscaled           "mus-lfloat-unscaled"
#define S_mus_lint                      "mus-lint"
#define S_mus_lintn                     "mus-lintn"
#define S_mus_lshort                    "mus-lshort"
#define S_mus_make_error                "mus-make-error"
#define S_mus_mulaw                     "mus-mulaw"
#define S_mus_next                      "mus-next"
#define S_mus_nist                      "mus-nist"
#define S_mus_out_format                "mus-out-format"
#define S_mus_raw                       "mus-raw"
#define S_mus_riff                      "mus-riff"
#define S_mus_sound_chans               "mus-sound-chans"
#define S_mus_sound_close_input         "mus-sound-close-input"
#define S_mus_sound_close_output        "mus-sound-close-output"
#define S_mus_sound_comment             "mus-sound-comment"
#define S_mus_sound_data_format         "mus-sound-data-format"
#define S_mus_sound_data_location       "mus-sound-data-location"
#define S_mus_sound_datum_size          "mus-sound-datum-size"
#define S_mus_sound_duration            "mus-sound-duration"
#define S_mus_sound_forget              "mus-sound-forget"
#define S_mus_sound_frames              "mus-sound-frames"
#define S_mus_sound_header_type         "mus-sound-header-type"
#define S_mus_sound_length              "mus-sound-length"
#define S_mus_sound_loop_info           "mus-sound-loop-info"
#define S_mus_sound_maxamp              "mus-sound-maxamp"
#define S_mus_sound_maxamp_exists       "mus-sound-maxamp-exists?"
#define S_mus_sound_open_input          "mus-sound-open-input"
#define S_mus_sound_open_output         "mus-sound-open-output"
#define S_mus_sound_prune               "mus-sound-prune"
#define S_mus_sound_read                "mus-sound-read"
#define S_mus_sound_reopen_output       "mus-sound-reopen-output"
#define S_mus_sound_report_cache        "mus-sound-report-cache"
#define S_mus_sound_samples             "mus-sound-samples"
#define S_mus_sound_seek_frame          "mus-sound-seek-frame"
#define S_mus_sound_srate               "mus-sound-srate"
#define S_mus_sound_type_specifier      "mus-sound-type-specifier"
#define S_mus_sound_write               "mus-sound-write"
#define S_mus_sound_write_date          "mus-sound-write-date"
#define S_mus_soundfont                 "mus-soundfont"
#define S_mus_svx                       "mus-svx"
#define S_mus_ubshort                   "mus-ubshort"
#define S_mus_ubyte                     "mus-ubyte"
#define S_mus_ulshort                   "mus-ulshort"
#define S_mus_unknown                   "mus-unknown"
#define S_mus_unsupported               "mus-unsupported"
#define S_mus_voc                       "mus-voc"
#define S_new_sound_hook                "new-sound-hook"
#define S_sound_data_to_vct             "sound-data->vct"
#define S_sound_data_chans              "sound-data-chans"
#define S_sound_data_length             "sound-data-length"
#define S_sound_data_maxamp             "sound-data-maxamp"
#define S_sound_data_p                  "sound-data?"
#define S_sound_data_ref                "sound-data-ref"
#define S_sound_data_setB               "sound-data-set!"
#define S_vct_to_sound_data             "vct->sound-data"

#endif

==> snd-7.13.tar.gz: snd-7/sndlib-strings.h <==
#ifndef SNDLIB_STRINGS_H
#define SNDLIB_STRINGS_H

#define S_array_to_file                 "array->file"
#define S_file_to_array                 "file->array"
#define S_make_sound_data               "make-sound-data"
#define S_mus_aifc                      "mus-aifc"
#define S_mus_aiff                      "mus-aiff"
#define S_mus_alaw                      "mus-alaw"
#define S_mus_audio_adat_in             "mus-audio-adat-in"
#define S_mus_audio_adat_out            "mus-audio-adat-out"
#define S_mus_audio_aes_in              "mus-audio-aes-in"
#define S_mus_audio_aes_out             "mus-audio-aes-out"
#define S_mus_audio_amp                 "mus-audio-amp"
#define S_mus_audio_aux_input           "mus-audio-aux-input"
#define S_mus_audio_aux_output          "mus-audio-aux-output"
#define S_mus_audio_bass                "mus-audio-bass"
#define S_mus_audio_cd                  "mus-audio-cd"
#define S_mus_audio_channel             "mus-audio-channel"
#define S_mus_audio_close               "mus-audio-close"
#define S_mus_audio_dac_filter          "mus-audio-dac-filter"
#define S_mus_audio_dac_out             "mus-audio-dac-out"
#define S_mus_audio_default             "mus-audio-default"
#define S_mus_audio_digital_in          "mus-audio-digital-in"
#define S_mus_audio_digital_out         "mus-audio-digital-out"
#define S_mus_audio_direction           "mus-audio-direction"
#define S_mus_audio_duplex_default      "mus-audio-duplex-default"
#define S_mus_audio_format              "mus-audio-format"
#define S_mus_audio_igain               "mus-audio-igain"
#define S_mus_audio_imix                "mus-audio-imix"
#define S_mus_audio_line                "mus-audio-line"
#define S_mus_audio_line1               "mus-audio-line1"
#define S_mus_audio_line2               "mus-audio-line2"
#define S_mus_audio_line3               "mus-audio-line3"
#define S_mus_audio_line_in             "mus-audio-line-in"
#define S_mus_audio_line_out            "mus-audio-line-out"
#define S_mus_audio_microphone          "mus-audio-microphone"
#define S_mus_audio_mixer               "mus-audio-mixer"
#define S_mus_audio_mixer_read          "mus-audio-mixer-read"
#define S_mus_audio_mixer_write         "mus-audio-mixer-write"
#define S_mus_audio_ogain               "mus-audio-ogain"
#define S_mus_audio_open_input          "mus-audio-open-input"
#define S_mus_audio_open_output         "mus-audio-open-output"
#define S_mus_audio_pcm                 "mus-audio-pcm"
#define S_mus_audio_pcm2                "mus-audio-pcm2"
#define S_mus_audio_port                "mus-audio-port"
#define S_mus_audio_read                "mus-audio-read"
#define S_mus_audio_reclev              "mus-audio-reclev"
#define S_mus_audio_report              "mus-audio-report"
#define S_mus_audio_samples_per_channel "mus-audio-samples-per-channel"
#define S_mus_audio_set_oss_buffers     "mus-audio-set-oss-buffers"
#define S_mus_audio_spdif_in            "mus-audio-spdif-in"
#define S_mus_audio_spdif_out           "mus-audio-spdif-out"
#define S_mus_audio_speakers            "mus-audio-speakers"
#define S_mus_audio_srate               "mus-audio-srate"
#define S_mus_audio_sun_outputs         "mus-audio-sun-outputs"
#define S_mus_audio_synth               "mus-audio-synth"
#define S_mus_audio_systems             "mus-audio-systems"
#define S_mus_audio_treble              "mus-audio-treble"
#define S_mus_audio_write               "mus-audio-write"
#define S_mus_b24int                    "mus-b24int"
#define S_mus_bdouble                   "mus-bdouble"
#define S_mus_bdouble_unscaled          "mus-bdouble-unscaled"
#define S_mus_bfloat                    "mus-bfloat"
#define S_mus_bfloat_unscaled           "mus-bfloat-unscaled"
#define S_mus_bicsf                     "mus-bicsf"
#define S_mus_bint                      "mus-bint"
#define S_mus_bintn                     "mus-bintn"
#define S_mus_bshort                    "mus-bshort"
#define S_mus_byte                      "mus-byte"
#define S_mus_bytes_per_sample          "mus-bytes-per-sample"
#define S_mus_data_format_name          "mus-data-format-name"
#define S_mus_data_format_to_string     "mus-data-format->string"
#define S_mus_error_type_to_string      "mus-error-type->string"
#define S_mus_expand_filename           "mus-expand-filename"
#define S_mus_file_data_clipped         "mus-file-data-clipped"
#define S_mus_file_prescaler            "mus-file-prescaler"
#define S_mus_header_type_name          "mus-header-type-name"
#define S_mus_header_type_to_string     "mus-header-type->string"
#define S_mus_ircam                     "mus-ircam"
#define S_mus_l24int                    "mus-l24int"
#define S_mus_ldouble                   "mus-ldouble"
#define S_mus_ldouble_unscaled          "mus-ldouble-unscaled"
#define S_mus_lfloat                    "mus-lfloat"
#define S_mus_lfloat_unscaled           "mus-lfloat-unscaled"
#define S_mus_lint                      "mus-lint"
#define S_mus_lintn                     "mus-lintn"
#define S_mus_lshort                    "mus-lshort"
#define S_mus_make_error                "mus-make-error"
#define S_mus_mulaw                     "mus-mulaw"
#define S_mus_next                      "mus-next"
#define S_mus_nist                      "mus-nist"
#define S_mus_out_format                "mus-out-format"
#define S_mus_raw                       "mus-raw"
#define S_mus_riff                      "mus-riff"
#define S_mus_sound_chans               "mus-sound-chans"
#define S_mus_sound_close_input         "mus-sound-close-input"
#define S_mus_sound_close_output        "mus-sound-close-output"
#define S_mus_sound_comment             "mus-sound-comment"
#define S_mus_sound_data_format         "mus-sound-data-format"
#define S_mus_sound_data_location       "mus-sound-data-location"
#define S_mus_sound_datum_size          "mus-sound-datum-size"
#define S_mus_sound_duration            "mus-sound-duration"
#define S_mus_sound_forget              "mus-sound-forget"
#define S_mus_sound_frames              "mus-sound-frames"
#define S_mus_sound_header_type         "mus-sound-header-type"
#define S_mus_sound_length              "mus-sound-length"
#define S_mus_sound_loop_info           "mus-sound-loop-info"
#define S_mus_sound_maxamp              "mus-sound-maxamp"
#define S_mus_sound_maxamp_exists       "mus-sound-maxamp-exists?"
#define S_mus_sound_open_input          "mus-sound-open-input"
#define S_mus_sound_open_output         "mus-sound-open-output"
#define S_mus_sound_prune               "mus-sound-prune"
#define S_mus_sound_read                "mus-sound-read"
#define S_mus_sound_reopen_output       "mus-sound-reopen-output"
#define S_mus_sound_report_cache        "mus-sound-report-cache"
#define S_mus_sound_samples             "mus-sound-samples"
#define S_mus_sound_seek_frame          "mus-sound-seek-frame"
#define S_mus_sound_srate               "mus-sound-srate"
#define S_mus_sound_type_specifier      "mus-sound-type-specifier"
#define S_mus_sound_write               "mus-sound-write"
#define S_mus_sound_write_date          "mus-sound-write-date"
#define S_mus_soundfont                 "mus-soundfont"
#define S_mus_svx                       "mus-svx"
#define S_mus_ubshort                   "mus-ubshort"
#define S_mus_ubyte                     "mus-ubyte"
#define S_mus_ulshort                   "mus-ulshort"
#define S_mus_unknown                   "mus-unknown"
#define S_mus_unsupported               "mus-unsupported"
#define S_mus_voc                       "mus-voc"
#define S_new_sound_hook                "new-sound-hook"
#define S_sound_data_to_vct             "sound-data->vct"
#define S_sound_data_chans              "sound-data-chans"
#define S_sound_data_length             "sound-data-length"
#define S_sound_data_maxamp             "sound-data-maxamp"
#define S_sound_data_p                  "sound-data?"
#define S_sound_data_ref                "sound-data-ref"
#define S_sound_data_setB               "sound-data-set!"
#define S_vct_to_sound_data             "vct->sound-data"

#endif
